Module: Pescheck
- Defined in:
- lib/pescheck-client/version.rb,
lib/pescheck-client.rb,
lib/pescheck-client/api_error.rb,
lib/pescheck-client/api_client.rb,
lib/pescheck-client/configuration.rb,
lib/pescheck-client/api/checks_api.rb,
lib/pescheck-client/api/o_auth_api.rb,
lib/pescheck-client/api_model_base.rb,
lib/pescheck-client/models/webhook.rb,
lib/pescheck-client/models/v2_money.rb,
lib/pescheck-client/api/profiles_api.rb,
lib/pescheck-client/api/webhooks_api.rb,
lib/pescheck-client/api/divisions_api.rb,
lib/pescheck-client/api/screenings_api.rb,
lib/pescheck-client/models/v2_document.rb,
lib/pescheck-client/models/jwt_response.rb,
lib/pescheck-client/models/v2_candidate.rb,
lib/pescheck-client/models/token_refresh.rb,
lib/pescheck-client/models/v2_check_info.rb,
lib/pescheck-client/models/division_write.rb,
lib/pescheck-client/models/jwt_generation.rb,
lib/pescheck-client/models/v2_check_field.rb,
lib/pescheck-client/models/verify_webhook.rb,
lib/pescheck-client/api/authentication_api.rb,
lib/pescheck-client/models/v2_profile_check.rb,
lib/pescheck-client/models/webhook_response.rb,
lib/pescheck-client/models/v2_profile_create.rb,
lib/pescheck-client/models/v2_profile_detail.rb,
lib/pescheck-client/models/v2_profile_update.rb,
lib/pescheck-client/models/division_read_only.rb,
lib/pescheck-client/models/o_auth_application.rb,
lib/pescheck-client/models/v2_screening_check.rb,
lib/pescheck-client/models/v2_document_content.rb,
lib/pescheck-client/models/v2_screening_create.rb,
lib/pescheck-client/models/v2_screening_detail.rb,
lib/pescheck-client/models/v2_profile_list_item.rb,
lib/pescheck-client/models/patched_division_write.rb,
lib/pescheck-client/models/v2_profile_check_entry.rb,
lib/pescheck-client/models/v2_screening_list_item.rb,
lib/pescheck-client/models/v2_profile_update_check.rb,
lib/pescheck-client/models/custom_token_obtain_pair.rb,
lib/pescheck-client/models/v2_screening_check_entry.rb,
lib/pescheck-client/models/o_auth_application_response.rb,
lib/pescheck-client/models/v2_screening_detail_profile.rb,
lib/pescheck-client/models/v2_screening_check_list_item.rb,
lib/pescheck-client/models/paginated_division_read_only_list.rb,
lib/pescheck-client/models/patched_v2_profile_partial_update.rb,
lib/pescheck-client/models/paginated_v2_profile_list_item_list.rb,
lib/pescheck-client/models/paginated_v2_screening_list_item_list.rb
Overview
#Pescheck API
#Official client library for the Pescheck API (v2), generated from the OpenAPI specification. Authenticate with OAuth2 client credentials and use the checks, profiles, screenings, webhooks and divisions endpoints. See https://github.com/pescheckit/pescheck-clients for installation and usage.
The version of the OpenAPI document: 2.0.0
Generated by: https://openapi-generator.tech Generator version: 7.23.0
Defined Under Namespace
Classes: ApiClient, ApiError, ApiModelBase, AuthenticationApi, ChecksApi, Configuration, CustomTokenObtainPair, DivisionReadOnly, DivisionWrite, DivisionsApi, JWTGeneration, JWTResponse, OAuthApi, OAuthApplication, OAuthApplicationResponse, PaginatedDivisionReadOnlyList, PaginatedV2ProfileListItemList, PaginatedV2ScreeningListItemList, PatchedDivisionWrite, PatchedV2ProfilePartialUpdate, ProfilesApi, ScreeningsApi, TokenRefresh, V2Candidate, V2CheckField, V2CheckInfo, V2Document, V2DocumentContent, V2Money, V2ProfileCheck, V2ProfileCheckEntry, V2ProfileCreate, V2ProfileDetail, V2ProfileListItem, V2ProfileUpdate, V2ProfileUpdateCheck, V2ScreeningCheck, V2ScreeningCheckEntry, V2ScreeningCheckListItem, V2ScreeningCreate, V2ScreeningDetail, V2ScreeningDetailProfile, V2ScreeningListItem, VerifyWebhook, Webhook, WebhookResponse, WebhooksApi
Constant Summary collapse
- VERSION =
'0.4.2'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. Pescheck.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
75 76 77 78 79 80 81 |
# File 'lib/pescheck-client.rb', line 75 def configure if block_given? yield(Configuration.default) else Configuration.default end end |