Class: Pescheck::OAuthApplicationResponse

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck-client/models/o_auth_application_response.rb

Overview

Serializer for OAuth application responses

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OAuthApplicationResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::OAuthApplicationResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::OAuthApplicationResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'client_secret')
    self.client_secret = attributes[:'client_secret']
  else
    self.client_secret = nil
  end

  if attributes.key?(:'client_type')
    self.client_type = attributes[:'client_type']
  else
    self.client_type = nil
  end

  if attributes.key?(:'authorization_grant_type')
    self.authorization_grant_type = attributes[:'authorization_grant_type']
  else
    self.authorization_grant_type = nil
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  else
    self.updated = nil
  end
end

Instance Attribute Details

#authorization_grant_typeObject

  • authorization-code - Authorization code * implicit - Implicit * password - Resource owner password-based * client-credentials - Client credentials * openid-hybrid - OpenID connect hybrid


31
32
33
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 31

def authorization_grant_type
  @authorization_grant_type
end

#client_idObject

Returns the value of attribute client_id.



23
24
25
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 23

def client_id
  @client_id
end

#client_secretObject

Returns the value of attribute client_secret.



25
26
27
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 25

def client_secret
  @client_secret
end

#client_typeObject

  • confidential - Confidential * public - Public


28
29
30
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 28

def client_type
  @client_type
end

#createdObject

Returns the value of attribute created.



33
34
35
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 33

def created
  @created
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 19

def id
  @id
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 21

def name
  @name
end

#updatedObject

Returns the value of attribute updated.



35
36
37
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 35

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'client_id' => :'client_id',
    :'client_secret' => :'client_secret',
    :'client_type' => :'client_type',
    :'authorization_grant_type' => :'authorization_grant_type',
    :'created' => :'created',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 341

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 84

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'client_id' => :'String',
    :'client_secret' => :'String',
    :'client_type' => :'String',
    :'authorization_grant_type' => :'String',
    :'created' => :'Time',
    :'updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 313

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      client_id == o.client_id &&
      client_secret == o.client_secret &&
      client_type == o.client_type &&
      authorization_grant_type == o.authorization_grant_type &&
      created == o.created &&
      updated == o.updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


328
329
330
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 328

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



334
335
336
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 334

def hash
  [id, name, client_id, client_secret, client_type, authorization_grant_type, created, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if !@client_id.nil? && @client_id.to_s.length > 100
    invalid_properties.push('invalid value for "client_id", the character length must be smaller than or equal to 100.')
  end

  if @client_secret.nil?
    invalid_properties.push('invalid value for "client_secret", client_secret cannot be nil.')
  end

  if @client_type.nil?
    invalid_properties.push('invalid value for "client_type", client_type cannot be nil.')
  end

  if @authorization_grant_type.nil?
    invalid_properties.push('invalid value for "authorization_grant_type", authorization_grant_type cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/pescheck-client/models/o_auth_application_response.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if !@name.nil? && @name.to_s.length > 255
  return false if !@client_id.nil? && @client_id.to_s.length > 100
  return false if @client_secret.nil?
  return false if @client_type.nil?
  client_type_validator = EnumAttributeValidator.new('String', ["confidential", "public"])
  return false unless client_type_validator.valid?(@client_type)
  return false if @authorization_grant_type.nil?
  authorization_grant_type_validator = EnumAttributeValidator.new('String', ["authorization-code", "implicit", "password", "client-credentials", "openid-hybrid"])
  return false unless authorization_grant_type_validator.valid?(@authorization_grant_type)
  return false if @created.nil?
  return false if @updated.nil?
  true
end