Class: Pescheck::V2ProfileDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck-client/models/v2_profile_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V2ProfileDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ProfileDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ProfileDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'is_custom')
    self.is_custom = attributes[:'is_custom']
  end

  if attributes.key?(:'checks')
    if (value = attributes[:'checks']).is_a?(Array)
      self.checks = value
    end
  else
    self.checks = nil
  end

  if attributes.key?(:'total_price')
    self.total_price = attributes[:'total_price']
  else
    self.total_price = nil
  end

  if attributes.key?(:'supported_countries_of_work')
    if (value = attributes[:'supported_countries_of_work']).is_a?(Array)
      self.supported_countries_of_work = value
    end
  else
    self.supported_countries_of_work = nil
  end

  if attributes.key?(:'supported_countries_of_residence')
    if (value = attributes[:'supported_countries_of_residence']).is_a?(Array)
      self.supported_countries_of_residence = value
    end
  else
    self.supported_countries_of_residence = nil
  end

  if attributes.key?(:'candidate_fields')
    if (value = attributes[:'candidate_fields']).is_a?(Array)
      self.candidate_fields = value
    end
  else
    self.candidate_fields = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#candidate_fieldsObject

Returns the value of attribute candidate_fields.



34
35
36
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 34

def candidate_fields
  @candidate_fields
end

#checksObject

Returns the value of attribute checks.



26
27
28
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 26

def checks
  @checks
end

#created_atObject

Returns the value of attribute created_at.



36
37
38
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 36

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 22

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 18

def id
  @id
end

#is_customObject

Returns the value of attribute is_custom.



24
25
26
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 24

def is_custom
  @is_custom
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 20

def name
  @name
end

#supported_countries_of_residenceObject

Returns the value of attribute supported_countries_of_residence.



32
33
34
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 32

def supported_countries_of_residence
  @supported_countries_of_residence
end

#supported_countries_of_workObject

Returns the value of attribute supported_countries_of_work.



30
31
32
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 30

def supported_countries_of_work
  @supported_countries_of_work
end

#total_priceObject

Returns the value of attribute total_price.



28
29
30
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 28

def total_price
  @total_price
end

#updated_atObject

Returns the value of attribute updated_at.



38
39
40
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 38

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'is_custom' => :'is_custom',
    :'checks' => :'checks',
    :'total_price' => :'total_price',
    :'supported_countries_of_work' => :'supported_countries_of_work',
    :'supported_countries_of_residence' => :'supported_countries_of_residence',
    :'candidate_fields' => :'candidate_fields',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 363

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 85

def self.openapi_nullable
  Set.new([
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 68

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'is_custom' => :'Boolean',
    :'checks' => :'Array<V2ProfileCheckEntry>',
    :'total_price' => :'V2Money',
    :'supported_countries_of_work' => :'Array<String>',
    :'supported_countries_of_residence' => :'Array<String>',
    :'candidate_fields' => :'Array<Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 332

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      is_custom == o.is_custom &&
      checks == o.checks &&
      total_price == o.total_price &&
      supported_countries_of_work == o.supported_countries_of_work &&
      supported_countries_of_residence == o.supported_countries_of_residence &&
      candidate_fields == o.candidate_fields &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


350
351
352
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 350

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



356
357
358
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 356

def hash
  [id, name, description, is_custom, checks, total_price, supported_countries_of_work, supported_countries_of_residence, candidate_fields, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @checks.nil?
    invalid_properties.push('invalid value for "checks", checks cannot be nil.')
  end

  if @total_price.nil?
    invalid_properties.push('invalid value for "total_price", total_price cannot be nil.')
  end

  if @supported_countries_of_work.nil?
    invalid_properties.push('invalid value for "supported_countries_of_work", supported_countries_of_work cannot be nil.')
  end

  if @supported_countries_of_residence.nil?
    invalid_properties.push('invalid value for "supported_countries_of_residence", supported_countries_of_residence cannot be nil.')
  end

  if @candidate_fields.nil?
    invalid_properties.push('invalid value for "candidate_fields", candidate_fields cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 385

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/pescheck-client/models/v2_profile_detail.rb', line 226

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @checks.nil?
  return false if @total_price.nil?
  return false if @supported_countries_of_work.nil?
  return false if @supported_countries_of_residence.nil?
  return false if @candidate_fields.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end