Class: Pescheck::V2ScreeningNote

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck-client/models/v2_screening_note.rb

Overview

A note recorded on the screening. check_id is the Check the note targets (null for type-only or unscoped notes).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ V2ScreeningNote

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ScreeningNote` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ScreeningNote`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  else
    self.note = nil
  end

  if attributes.key?(:'check_type')
    self.check_type = attributes[:'check_type']
  else
    self.check_type = nil
  end

  if attributes.key?(:'check_id')
    self.check_id = attributes[:'check_id']
  else
    self.check_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#check_idObject

Returns the value of attribute check_id.



23
24
25
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 23

def check_id
  @check_id
end

#check_typeObject

Returns the value of attribute check_type.



21
22
23
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 21

def check_type
  @check_type
end

#created_atObject

Returns the value of attribute created_at.



25
26
27
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 25

def created_at
  @created_at
end

#noteObject

Returns the value of attribute note.



19
20
21
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 19

def note
  @note
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 28

def self.attribute_map
  {
    :'note' => :'note',
    :'check_type' => :'check_type',
    :'check_id' => :'check_id',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
61
62
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 58

def self.openapi_nullable
  Set.new([
    :'check_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
55
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 48

def self.openapi_types
  {
    :'note' => :'String',
    :'check_type' => :'String',
    :'check_id' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      note == o.note &&
      check_type == o.check_type &&
      check_id == o.check_id &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 184

def hash
  [note, check_type, check_id, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @note.nil?
    invalid_properties.push('invalid value for "note", note cannot be nil.')
  end

  if @check_type.nil?
    invalid_properties.push('invalid value for "check_type", check_type cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
131
132
133
# File 'lib/pescheck-client/models/v2_screening_note.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @note.nil?
  return false if @check_type.nil?
  return false if @created_at.nil?
  true
end