Class: Pescheck::V2ScreeningNoteInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::V2ScreeningNoteInput
- Defined in:
- lib/pescheck-client/models/v2_screening_note_input.rb
Overview
A note to record on the screening at creation. Scope it to a specific check with profile_check_id (links the note to the Check spawned from that ProfileCheck) or to a check_type; profile_check_id wins when both are given. With neither, the note is recorded against the screening with no check (check_type 'other').
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#check_type ⇒ Object
Scope the note to a check type.
-
#note ⇒ Object
Returns the value of attribute note.
-
#profile_check_id ⇒ Object
Links the note to the Check spawned from this ProfileCheck.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V2ScreeningNoteInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V2ScreeningNoteInput
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ScreeningNoteInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ScreeningNoteInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'note') self.note = attributes[:'note'] else self.note = nil end if attributes.key?(:'profile_check_id') self.profile_check_id = attributes[:'profile_check_id'] end if attributes.key?(:'check_type') self.check_type = attributes[:'check_type'] end end |
Instance Attribute Details
#check_type ⇒ Object
Scope the note to a check type. Ignored when profile_check_id is given. * addresscheck - addresscheck * adversemedia2check - adversemedia2check * adversemediacheck - adversemediacheck * bigcheck - bigcheck * criminalrecordscheck - criminalrecordscheck * criminalrecordsuploadcheck - criminalrecordsuploadcheck * customintegritycheck - customintegritycheck * cvcheck - cvcheck * edrcheck - edrcheck * focumcheck - focumcheck * id2check - id2check * idcheck - idcheck * integritycheck - integritycheck * openhealthcarecheck - openhealthcarecheck * permissioncheck - permissioncheck * pescheckadversemediacheck - pescheckadversemediacheck * qualificationcheck - qualificationcheck * righttoworkcheck - righttoworkcheck * vogcheck - vogcheck * watchlist2check - watchlist2check * watchlistcheck - watchlistcheck * workreferencecheck - workreferencecheck * worldwidecreditcheck - worldwidecreditcheck
25 26 27 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 25 def check_type @check_type end |
#note ⇒ Object
Returns the value of attribute note.
19 20 21 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 19 def note @note end |
#profile_check_id ⇒ Object
Links the note to the Check spawned from this ProfileCheck. Wins over check_type.
22 23 24 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 22 def profile_check_id @profile_check_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 50 def self.attribute_map { :'note' => :'note', :'profile_check_id' => :'profile_check_id', :'check_type' => :'check_type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 78 def self.openapi_nullable Set.new([ :'profile_check_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 69 def self.openapi_types { :'note' => :'String', :'profile_check_id' => :'String', :'check_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && note == o.note && profile_check_id == o.profile_check_id && check_type == o.check_type end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 175 def hash [note, profile_check_id, check_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @note.nil? invalid_properties.push('invalid value for "note", note cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 134 135 |
# File 'lib/pescheck-client/models/v2_screening_note_input.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @note.nil? check_type_validator = EnumAttributeValidator.new('String', ["addresscheck", "adversemedia2check", "adversemediacheck", "bigcheck", "criminalrecordscheck", "criminalrecordsuploadcheck", "customintegritycheck", "cvcheck", "edrcheck", "focumcheck", "id2check", "idcheck", "integritycheck", "openhealthcarecheck", "permissioncheck", "pescheckadversemediacheck", "qualificationcheck", "righttoworkcheck", "vogcheck", "watchlist2check", "watchlistcheck", "workreferencecheck", "worldwidecreditcheck", ""]) return false unless check_type_validator.valid?(@check_type) true end |