Class: Pescheck::Webhook

Inherits:
ApiModelBase show all
Defined in:
lib/pescheck-client/models/webhook.rb

Overview

Serializer for webhook creation/update requests

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Webhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/pescheck-client/models/webhook.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::Webhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  else
    self.events = nil
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  else
    self.active = true
  end

  if attributes.key?(:'division_id')
    self.division_id = attributes[:'division_id']
  end
end

Instance Attribute Details

#activeObject

Whether the webhook is active



29
30
31
# File 'lib/pescheck-client/models/webhook.rb', line 29

def active
  @active
end

#division_idObject

Division ID to create webhook for (optional)



32
33
34
# File 'lib/pescheck-client/models/webhook.rb', line 32

def division_id
  @division_id
end

#eventsObject

List of events to subscribe to. Valid events: check.status_changed, screening.status_changed, screening.archived, package.created, package.updated, profile.created, profile.updated, division.created, division.updated



26
27
28
# File 'lib/pescheck-client/models/webhook.rb', line 26

def events
  @events
end

#nameObject

Descriptive name for this webhook



20
21
22
# File 'lib/pescheck-client/models/webhook.rb', line 20

def name
  @name
end

#urlObject

HTTPS URL where webhook events will be sent



23
24
25
# File 'lib/pescheck-client/models/webhook.rb', line 23

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/pescheck-client/models/webhook.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/pescheck-client/models/webhook.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/pescheck-client/models/webhook.rb', line 57

def self.attribute_map
  {
    :'name' => :'name',
    :'url' => :'url',
    :'events' => :'events',
    :'active' => :'active',
    :'division_id' => :'division_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/pescheck-client/models/webhook.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/pescheck-client/models/webhook.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/pescheck-client/models/webhook.rb', line 78

def self.openapi_types
  {
    :'name' => :'String',
    :'url' => :'String',
    :'events' => :'Array<String>',
    :'active' => :'Boolean',
    :'division_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
# File 'lib/pescheck-client/models/webhook.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      url == o.url &&
      events == o.events &&
      active == o.active &&
      division_id == o.division_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/pescheck-client/models/webhook.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/pescheck-client/models/webhook.rb', line 220

def hash
  [name, url, events, active, division_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/pescheck-client/models/webhook.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @events.nil?
    invalid_properties.push('invalid value for "events", events cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/pescheck-client/models/webhook.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
# File 'lib/pescheck-client/models/webhook.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @url.nil?
  return false if @events.nil?
  true
end