Class: Pescheck::DivisionReadOnly
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::DivisionReadOnly
- Defined in:
- lib/pescheck-client/models/division_read_only.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#city ⇒ Object
Returns the value of attribute city.
-
#contact_email ⇒ Object
Returns the value of attribute contact_email.
-
#contact_name ⇒ Object
Returns the value of attribute contact_name.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#invoice_email ⇒ Object
Returns the value of attribute invoice_email.
-
#name ⇒ Object
Returns the value of attribute name.
-
#parent ⇒ Object
Returns the value of attribute parent.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#postal ⇒ Object
Returns the value of attribute postal.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#use_parent_on_billing ⇒ Object
Returns the value of attribute use_parent_on_billing.
-
#use_parent_on_email ⇒ Object
Returns the value of attribute use_parent_on_email.
-
#use_parent_on_report ⇒ Object
Returns the value of attribute use_parent_on_report.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DivisionReadOnly
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DivisionReadOnly
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::DivisionReadOnly` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::DivisionReadOnly`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'parent') self.parent = attributes[:'parent'] else self.parent = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'postal') self.postal = attributes[:'postal'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'contact_name') self.contact_name = attributes[:'contact_name'] end if attributes.key?(:'contact_email') self.contact_email = attributes[:'contact_email'] end if attributes.key?(:'invoice_email') self.invoice_email = attributes[:'invoice_email'] end if attributes.key?(:'use_parent_on_email') self.use_parent_on_email = attributes[:'use_parent_on_email'] end if attributes.key?(:'use_parent_on_billing') self.use_parent_on_billing = attributes[:'use_parent_on_billing'] end if attributes.key?(:'use_parent_on_report') self.use_parent_on_report = attributes[:'use_parent_on_report'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
30 31 32 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 30 def address @address end |
#city ⇒ Object
Returns the value of attribute city.
28 29 30 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 28 def city @city end |
#contact_email ⇒ Object
Returns the value of attribute contact_email.
38 39 40 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 38 def contact_email @contact_email end |
#contact_name ⇒ Object
Returns the value of attribute contact_name.
36 37 38 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 36 def contact_name @contact_name end |
#created_at ⇒ Object
Returns the value of attribute created_at.
24 25 26 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 24 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 18 def id @id end |
#invoice_email ⇒ Object
Returns the value of attribute invoice_email.
40 41 42 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 40 def invoice_email @invoice_email end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 20 def name @name end |
#parent ⇒ Object
Returns the value of attribute parent.
22 23 24 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 22 def parent @parent end |
#phone ⇒ Object
Returns the value of attribute phone.
34 35 36 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 34 def phone @phone end |
#postal ⇒ Object
Returns the value of attribute postal.
32 33 34 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 32 def postal @postal end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
26 27 28 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 26 def updated_at @updated_at end |
#use_parent_on_billing ⇒ Object
Returns the value of attribute use_parent_on_billing.
44 45 46 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 44 def use_parent_on_billing @use_parent_on_billing end |
#use_parent_on_email ⇒ Object
Returns the value of attribute use_parent_on_email.
42 43 44 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 42 def use_parent_on_email @use_parent_on_email end |
#use_parent_on_report ⇒ Object
Returns the value of attribute use_parent_on_report.
46 47 48 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 46 def use_parent_on_report @use_parent_on_report end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 49 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'parent' => :'parent', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'city' => :'city', :'address' => :'address', :'postal' => :'postal', :'phone' => :'phone', :'contact_name' => :'contact_name', :'contact_email' => :'contact_email', :'invoice_email' => :'invoice_email', :'use_parent_on_email' => :'use_parent_on_email', :'use_parent_on_billing' => :'use_parent_on_billing', :'use_parent_on_report' => :'use_parent_on_report' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 431 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 101 def self.openapi_nullable Set.new([ :'name', :'city', :'address', :'postal', :'phone', :'contact_name', :'contact_email', :'invoice_email', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 80 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'parent' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time', :'city' => :'String', :'address' => :'String', :'postal' => :'String', :'phone' => :'String', :'contact_name' => :'String', :'contact_email' => :'String', :'invoice_email' => :'String', :'use_parent_on_email' => :'Boolean', :'use_parent_on_billing' => :'Boolean', :'use_parent_on_report' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 396 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && parent == o.parent && created_at == o.created_at && updated_at == o.updated_at && city == o.city && address == o.address && postal == o.postal && phone == o.phone && contact_name == o.contact_name && contact_email == o.contact_email && invoice_email == o.invoice_email && use_parent_on_email == o.use_parent_on_email && use_parent_on_billing == o.use_parent_on_billing && use_parent_on_report == o.use_parent_on_report end |
#eql?(o) ⇒ Boolean
418 419 420 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 418 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
424 425 426 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 424 def hash [id, name, parent, created_at, updated_at, city, address, postal, phone, contact_name, contact_email, invoice_email, use_parent_on_email, use_parent_on_billing, use_parent_on_report].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 201 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if !@name.nil? && @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @parent.nil? invalid_properties.push('invalid value for "parent", parent cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if !@city.nil? && @city.to_s.length > 255 invalid_properties.push('invalid value for "city", the character length must be smaller than or equal to 255.') end if !@address.nil? && @address.to_s.length > 255 invalid_properties.push('invalid value for "address", the character length must be smaller than or equal to 255.') end if !@postal.nil? && @postal.to_s.length > 20 invalid_properties.push('invalid value for "postal", the character length must be smaller than or equal to 20.') end if !@phone.nil? && @phone.to_s.length > 20 invalid_properties.push('invalid value for "phone", the character length must be smaller than or equal to 20.') end if !@contact_name.nil? && @contact_name.to_s.length > 255 invalid_properties.push('invalid value for "contact_name", the character length must be smaller than or equal to 255.') end if !@contact_email.nil? && @contact_email.to_s.length > 254 invalid_properties.push('invalid value for "contact_email", the character length must be smaller than or equal to 254.') end if !@invoice_email.nil? && @invoice_email.to_s.length > 254 invalid_properties.push('invalid value for "invoice_email", the character length must be smaller than or equal to 254.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 453 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/pescheck-client/models/division_read_only.rb', line 257 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if !@name.nil? && @name.to_s.length > 255 return false if @parent.nil? return false if @created_at.nil? return false if @updated_at.nil? return false if !@city.nil? && @city.to_s.length > 255 return false if !@address.nil? && @address.to_s.length > 255 return false if !@postal.nil? && @postal.to_s.length > 20 return false if !@phone.nil? && @phone.to_s.length > 20 return false if !@contact_name.nil? && @contact_name.to_s.length > 255 return false if !@contact_email.nil? && @contact_email.to_s.length > 254 return false if !@invoice_email.nil? && @invoice_email.to_s.length > 254 true end |