Class: Pescheck::JWTResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::JWTResponse
- Defined in:
- lib/pescheck-client/models/jwt_response.rb
Overview
Serializer for JWT token response
Instance Attribute Summary collapse
-
#access_token ⇒ Object
JWT access token.
-
#expires_in ⇒ Object
Access token expiration in seconds.
-
#organisation ⇒ Object
Organization name.
-
#organisation_id ⇒ Object
Organization ID.
-
#refresh_token ⇒ Object
JWT refresh token.
-
#token_type ⇒ Object
Returns the value of attribute token_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ JWTResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ JWTResponse
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::JWTResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::JWTResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] else self.access_token = nil end if attributes.key?(:'refresh_token') self.refresh_token = attributes[:'refresh_token'] else self.refresh_token = nil end if attributes.key?(:'token_type') self.token_type = attributes[:'token_type'] else self.token_type = 'Bearer' end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] else self.expires_in = nil end if attributes.key?(:'organisation') self.organisation = attributes[:'organisation'] else self.organisation = nil end if attributes.key?(:'organisation_id') self.organisation_id = attributes[:'organisation_id'] else self.organisation_id = nil end end |
Instance Attribute Details
#access_token ⇒ Object
JWT access token
20 21 22 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 20 def access_token @access_token end |
#expires_in ⇒ Object
Access token expiration in seconds
28 29 30 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 28 def expires_in @expires_in end |
#organisation ⇒ Object
Organization name
31 32 33 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 31 def organisation @organisation end |
#organisation_id ⇒ Object
Organization ID
34 35 36 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 34 def organisation_id @organisation_id end |
#refresh_token ⇒ Object
JWT refresh token
23 24 25 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 23 def refresh_token @refresh_token end |
#token_type ⇒ Object
Returns the value of attribute token_type.
25 26 27 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 25 def token_type @token_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 37 def self.attribute_map { :'access_token' => :'access_token', :'refresh_token' => :'refresh_token', :'token_type' => :'token_type', :'expires_in' => :'expires_in', :'organisation' => :'organisation', :'organisation_id' => :'organisation_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 59 def self.openapi_types { :'access_token' => :'String', :'refresh_token' => :'String', :'token_type' => :'String', :'expires_in' => :'Integer', :'organisation' => :'String', :'organisation_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && access_token == o.access_token && refresh_token == o.refresh_token && token_type == o.token_type && expires_in == o.expires_in && organisation == o.organisation && organisation_id == o.organisation_id end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 240 def hash [access_token, refresh_token, token_type, expires_in, organisation, organisation_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @access_token.nil? invalid_properties.push('invalid value for "access_token", access_token cannot be nil.') end if @refresh_token.nil? invalid_properties.push('invalid value for "refresh_token", refresh_token cannot be nil.') end if @expires_in.nil? invalid_properties.push('invalid value for "expires_in", expires_in cannot be nil.') end if @organisation.nil? invalid_properties.push('invalid value for "organisation", organisation cannot be nil.') end if @organisation_id.nil? invalid_properties.push('invalid value for "organisation_id", organisation_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 165 166 167 |
# File 'lib/pescheck-client/models/jwt_response.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @access_token.nil? return false if @refresh_token.nil? return false if @expires_in.nil? return false if @organisation.nil? return false if @organisation_id.nil? true end |