Class: Pescheck::V2ScreeningDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Pescheck::V2ScreeningDetail
- Defined in:
- lib/pescheck-client/models/v2_screening_detail.rb
Instance Attribute Summary collapse
-
#candidate ⇒ Object
Returns the value of attribute candidate.
-
#candidate_wizard_url ⇒ Object
Public wizard URL for the candidate.
-
#checks ⇒ Object
Returns the value of attribute checks.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#dashboard_url ⇒ Object
Dashboard URL for this screening.
-
#id ⇒ Object
Returns the value of attribute id.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#screening_notes ⇒ Object
Returns the value of attribute screening_notes.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V2ScreeningDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ V2ScreeningDetail
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Pescheck::V2ScreeningDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Pescheck::V2ScreeningDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'profile') self.profile = attributes[:'profile'] else self.profile = nil end if attributes.key?(:'candidate') self.candidate = attributes[:'candidate'] else self.candidate = nil end if attributes.key?(:'checks') if (value = attributes[:'checks']).is_a?(Array) self.checks = value end else self.checks = nil end if attributes.key?(:'screening_notes') if (value = attributes[:'screening_notes']).is_a?(Array) self.screening_notes = value end else self.screening_notes = nil end if attributes.key?(:'candidate_wizard_url') self.candidate_wizard_url = attributes[:'candidate_wizard_url'] else self.candidate_wizard_url = nil end if attributes.key?(:'dashboard_url') self.dashboard_url = attributes[:'dashboard_url'] else self.dashboard_url = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end end |
Instance Attribute Details
#candidate ⇒ Object
Returns the value of attribute candidate.
24 25 26 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 24 def candidate @candidate end |
#candidate_wizard_url ⇒ Object
Public wizard URL for the candidate. Null when no check needs candidate input.
31 32 33 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 31 def candidate_wizard_url @candidate_wizard_url end |
#checks ⇒ Object
Returns the value of attribute checks.
26 27 28 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 26 def checks @checks end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 36 def created_at @created_at end |
#dashboard_url ⇒ Object
Dashboard URL for this screening.
34 35 36 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 34 def dashboard_url @dashboard_url end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 18 def id @id end |
#profile ⇒ Object
Returns the value of attribute profile.
22 23 24 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 22 def profile @profile end |
#screening_notes ⇒ Object
Returns the value of attribute screening_notes.
28 29 30 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 28 def screening_notes @screening_notes end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 20 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
38 39 40 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 38 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 41 def self.attribute_map { :'id' => :'id', :'status' => :'status', :'profile' => :'profile', :'candidate' => :'candidate', :'checks' => :'checks', :'screening_notes' => :'screening_notes', :'candidate_wizard_url' => :'candidate_wizard_url', :'dashboard_url' => :'dashboard_url', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 338 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 87 88 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 83 def self.openapi_nullable Set.new([ :'profile', :'candidate_wizard_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 67 def self.openapi_types { :'id' => :'String', :'status' => :'String', :'profile' => :'V2ScreeningDetailProfile', :'candidate' => :'V2Candidate', :'checks' => :'Array<V2ScreeningCheckEntry>', :'screening_notes' => :'Array<V2ScreeningNote>', :'candidate_wizard_url' => :'String', :'dashboard_url' => :'String', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 308 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && status == o.status && profile == o.profile && candidate == o.candidate && checks == o.checks && screening_notes == o.screening_notes && candidate_wizard_url == o.candidate_wizard_url && dashboard_url == o.dashboard_url && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
325 326 327 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 325 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
331 332 333 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 331 def hash [id, status, profile, candidate, checks, screening_notes, candidate_wizard_url, dashboard_url, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @candidate.nil? invalid_properties.push('invalid value for "candidate", candidate cannot be nil.') end if @checks.nil? invalid_properties.push('invalid value for "checks", checks cannot be nil.') end if @screening_notes.nil? invalid_properties.push('invalid value for "screening_notes", screening_notes cannot be nil.') end if @dashboard_url.nil? invalid_properties.push('invalid value for "dashboard_url", dashboard_url cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 360 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/pescheck-client/models/v2_screening_detail.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @status.nil? return false if @candidate.nil? return false if @checks.nil? return false if @screening_notes.nil? return false if @dashboard_url.nil? return false if @created_at.nil? return false if @updated_at.nil? true end |